==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24TitlePaneLayout.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$TitlePaneLayout

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c54767cd8347a726 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$addLayoutComponent$784c308b12270c9d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$removeLayoutComponent$94e2b376e31bbde2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Component$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$addLayoutComponent$784c308b12270c9d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$removeLayoutComponent$94e2b376e31bbde2;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vmethods {
	void	(*addLayoutComponent$784c308b12270c9d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *);
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *);
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *);
	void	(*removeLayoutComponent$94e2b376e31bbde2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Component$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24TitlePaneLayout.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$TitlePaneLayout

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2ab0ed72e09adf1e javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$addLayoutComponent$784c308b12270c9d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$layoutContainer$8a99e8b5ce38e753(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$minimumLayoutSize$42562182f8f0cd6a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$preferredLayoutSize$4c5cb50e6266027d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method$removeLayoutComponent$94e2b376e31bbde2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$addLayoutComponent$784c308b12270c9d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$layoutContainer$8a99e8b5ce38e753;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$minimumLayoutSize$42562182f8f0cd6a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$preferredLayoutSize$4c5cb50e6266027d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$method_info$removeLayoutComponent$94e2b376e31bbde2;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vmethods {
	void	(*addLayoutComponent$784c308b12270c9d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_lang_String$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	void	(*layoutContainer$8a99e8b5ce38e753)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*minimumLayoutSize$42562182f8f0cd6a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*preferredLayoutSize$4c5cb50e6266027d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;
	void	(*removeLayoutComponent$94e2b376e31bbde2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24TitlePaneLayout_H_ */
